@@ -42,11 +42,11 @@ class TestQuery:
         assert type(q) == list
         assert len(q) > 0
 
-    # def test_find_contradictions(self):
-    #     q = query.find_contradictions()
-    #     assert type(q) == Client
-    #     assert len(q.data) > 0
-    #     assert len(q.table.columns) > 5
+    def test_find_contradictions(self):
+        q = query.find_contradictions()
+        assert type(q) == Client
+        assert len(q.data) > 0
+        assert len(q.table.columns) > 5
 
 
 # TODO write tests for "subgraph"
